package com.edgec.browserbackend.browser.controller;

import com.edgec.browserbackend.account.dto.ResultDto;
import com.edgec.browserbackend.browser.domain.UserCode;
import com.edgec.browserbackend.browser.dto.FavoriteUrl;
import com.edgec.browserbackend.browser.service.ShopService;
import com.edgec.browserbackend.browser.service.TempService;
import com.edgec.browserbackend.common.commons.error.ClientRequestException;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.security.Principal;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 一些临时执行的代码可以放在这里，方便删除
 */
@RestController
@RequestMapping("/temp")
public class TempController {

    @Autowired
    private TempService tempService;

    @Autowired
    private ShopService shopService;

    /**
     * 记住用户明文密码
     */
    @PostMapping(value = "/usercode")
    public void addUserCode(@RequestBody UserCode userCode) {
        tempService.save(userCode);
    }

    @GetMapping("/{ip}")
    public String getPassword(@PathVariable("ip") String ip) {
        return tempService.getPassword(ip);
    }

    /**
     * 店铺收藏夹
     */
    @GetMapping("/favorites/{shopId}")
    public ResultDto getFavoritesByShopId(Principal principal, @PathVariable("shopId") String shopId) {
        ResultDto resultDto = new ResultDto();
        try {
            List<FavoriteUrl> list = shopService.getFavoritesByShopId(principal.getName(), shopId);
            resultDto.setData(list);
            resultDto.setStatus(0);
        } catch (ClientRequestException e) {
            dealClientRequestException(resultDto, e);
        }
        return resultDto;
    }

    /**
     * 店铺收藏夹 删除收藏
     */
    @DeleteMapping("/favorites/{shopId}")
    public ResultDto deleteFavoritesByShopId(Principal principal, @PathVariable("shopId") String shopId, @RequestBody FavoriteUrl favoriteUrl) {
        ResultDto resultDto = new ResultDto();
        try {
            resultDto.setData(shopService.deleteFavoritesByShopId(principal.getName(), shopId, favoriteUrl));
            resultDto.setStatus(0);
        } catch (ClientRequestException e) {
            dealClientRequestException(resultDto, e);
        }
        return resultDto;
    }

    /**
     * 店铺收藏夹 新增收藏
     */
    @PostMapping("/favorites/{shopId}")
    public ResultDto saveFavoritesByShopId(Principal principal, @PathVariable("shopId") String shopId, @RequestBody FavoriteUrl favoriteUrl) {
        ResultDto resultDto = new ResultDto();
        try {
            resultDto.setData(shopService.saveFavoritesByShopId(principal.getName(), shopId, favoriteUrl));
            resultDto.setStatus(0);
        } catch (ClientRequestException e) {
            dealClientRequestException(resultDto, e);
        }
        return resultDto;
    }

    private void dealClientRequestException(ResultDto resultDto, ClientRequestException e) {
        resultDto.setStatus(-1);
        Map<String, Object> statusInfo = new HashMap<>();
        statusInfo.put("code", e.getErrorCode());
        statusInfo.put("message", e.getMessage());
        resultDto.setStatusInfo(statusInfo);
    }

}
